import { ViewContainerRef, EventEmitter, QueryList, Type, ElementRef, SimpleChange, ChangeDetectorRef, TemplateRef } from '@angular/core';
export { ContentChild, Type, forwardRef } from '@angular/core';
export interface IParentTag {
    tags: Array<any>;
}
export interface IChildChange {
    index: number;
    change: any;
}
export interface IChangeSet {
    [key: string]: Array<IChildChange>;
}
/** Internal Helpers */
export declare class Utils {
    static IterateAndGetChanges(obj: IParentTag): IChangeSet;
    static AngularizeInputs(inputs: Array<string>, twoways: Array<string>): Array<string>;
}
export declare class EJComponents<W, T> implements IParentTag {
    protected controlName: string;
    protected el: ElementRef;
    protected cdRef: ChangeDetectorRef;
    tags: Array<any>;
    model: T;
    widget: W;
    protected outputs: Array<string>;
    protected inputs: Array<string>;
    protected twoways: Array<string>;
    protected complexProperties: Array<string>;
    protected isEditor: boolean;
    private firstCheck;
    constructor(controlName: string, el: ElementRef, cdRef: ChangeDetectorRef);
    protected createEvents(events: Array<string>): void;
    protected createTwoways(twoways: Array<string>): void;
    protected addTwoways(prop: any): Function;
    ngAfterContentInit(): void;
    private static bindAndRaiseEvent(instance, model, event);
    ngOnChanges(changes: {
        [key: string]: SimpleChange;
    }): void;
    ngAfterContentChecked(): void;
    ngOnDestroy(): void;
}
export declare class ComplexTagElement {
    recentChanges: any;
    hasChanges: boolean;
    firstChange: boolean;
    index: number;
    valueChange: EventEmitter<any>;
    protected complexProperties: Array<string>;
    property: string;
    parent: EJComponents<any, any>;
    inputs: Array<string>;
    tags: Array<string>;
    constructor();
    ngOnInit(): void;
    ensureCleanObject(): void;
    ngOnChanges(changes: {
        [key: string]: SimpleChange;
    }): void;
    getChangesAndReset(): any;
    ngAfterContentChecked(): void;
}
export declare class ArrayTagElement<T extends ComplexTagElement> {
    propertyName: string;
    list: Array<T>;
    children: QueryList<T>;
    recentChanges: Array<IChildChange>;
    hasChanges: boolean;
    constructor(propertyName: string);
    ngAfterContentInit(): void;
    ngOnChanges(changes: any): void;
    getList(): T[];
    getChangesAndReset(): Array<IChildChange>;
    ngAfterContentChecked(): void;
}
export declare function CreateComplexDirective(args: {
    selector: string;
    inputs: Array<string>;
    outputs?: Array<string>;
    queries?: {
        [key: string]: any;
    };
}, ejArgs: any): Type<any>;
export declare class EJTemplateDirective {
    protected el: ElementRef;
    protected viewContainerRef: ViewContainerRef;
    protected templateRef: TemplateRef<any>;
    element: any;
    private childViews;
    constructor(el: ElementRef, viewContainerRef: ViewContainerRef, templateRef: TemplateRef<any>);
    ngOnInit(): void;
    ngAfterViewInit(): void;
    compileTempalte(): void;
    clearTempalte(): void;
    ngOnDestroy(): void;
}
export declare function CreateArrayTagDirective(property: string, selector: string, type: any): Type<any>;
export declare function CreateComponent(controlName: string, componentArgs: {
    selector: string;
    inputs: Array<string>;
    outputs: Array<string>;
    template: string;
    changeDetection?: any;
    queries: {
        [key: string]: any;
    };
}, ejArgs: any): Type<any>;
export declare function CreateControlValueAccessor(selector: string, component: Type<any>): Type<any>;
